// Copyright (c) 2007 GeometryFactory (France). All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 3 of the License,
// or (at your option) any later version.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/next/Installation/include/CGAL/auto_link/CGALQt3.h $
// $Id: CGALQt3.h 67093 2012-01-13 11:22:39Z lrineau $
// 
//
// Author(s)     : Fernando Cacciola (fernando.cacciola@geometryfactry.com)

#ifndef CGAL_AUTO_LINK_CGALQT_H
#define CGAL_AUTO_LINK_CGALQT_H

#include <CGAL/config.h>

#ifndef CGAL_NO_AUTOLINK_CGALQT

#define CGAL_LIB_NAME CGAL_Qt3
#include <CGAL/auto_link/auto_link.h>

#endif // CGAL_NO_AUTOLINK_CGALQT

#endif // CGAL_AUTO_LINK_CGALQT_H
